@@ -27,4 +27,7 @@ class OrderType(Enum):
             return self.value == other.value
 
         else:
-            return OrderType.from_string(other) == self
\ No newline at end of file
+            return OrderType.from_value(other) == self
+
+    def __str__(self):
+        return str(self.value)
